@@ -10,18 +10,18 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
-$DATE = '2003/06/13';
+$VERSION = '0.04';
+$DATE = '2003/06/14';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_TestUtil.pm' => [qw(0.03 2003/06/13), 'revised 0.02'],
-    'MANIFEST' => [qw(0.03 2003/06/13), 'generated, replaces 0.02'],
-    'Makefile.PL' => [qw(0.03 2003/06/13), 'generated, replaces 0.02'],
-    'README' => [qw(0.03 2003/06/13), 'generated, replaces 0.02'],
-    'lib/Test/TestUtil.pm' => [qw(1.05 2003/06/13), 'revised 1.04'],
-    't/Test/TestUtil/TestUtil.t' => [qw(0.02 2003/06/13), 'revised 0.01'],
+    'lib/Docs/Site_SVD/Test_TestUtil.pm' => [qw(0.04 2003/06/14), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2003/06/14), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2003/06/14), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2003/06/14), 'generated, replaces 0.03'],
+    'lib/Test/TestUtil.pm' => [qw(1.06 2003/06/14), 'revised 1.05'],
+    't/Test/TestUtil/TestUtil.t' => [qw(0.03 2003/06/14), 'revised 0.02'],
     't/Test/TestUtil/Drivers/Driver.pm' => [qw(0.01 2003/06/12), 'unchanged'],
     't/Test/TestUtil/Drivers/Generate.pm' => [qw(0.01 2003/06/12), 'unchanged'],
     't/Test/TestUtil/Drivers/IO.pm' => [qw(0.01 2003/06/12), 'unchanged'],
@@ -51,11 +51,11 @@ use vars qw(%INVENTORY);
 
  Test::TestUtil - Utilites for Test::STDmaker and ExtUtils::SVDmaker
 
- Revision: B
+ Revision: C
 
- Version: 0.03
+ Version: 0.04
 
- Date: 2003/06/13
+ Date: 2003/06/14
 
  Prepared for: General Public 
 
@@ -103,8 +103,8 @@ The dependency of the program modules in the Test::STDmaker ExtUtils::SVDmaker
 US DOD STD2167A bundle is as follows:
 
  Test::TestUtil
-     Test::Tester
-        DataPort::FormDB
+     Test::Tech
+        DataPort::DataFile DataPort::FileType::FormDB
             Test::STDmaker ExtUtils::SVDmaker
 
 Test software should be short and not depend on any other
@@ -146,7 +146,7 @@ that the program module vocabulary is present.
 
 =head2 1.3 Document overview.
 
-This document releases Test::TestUtil version 0.03
+This document releases Test::TestUtil version 0.04
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -164,8 +164,8 @@ system file specification.
 This document releases the file found
 at the following repository:
 
-   http://www.softwarediamonds/packages/Test-TestUtil-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-TestUtil-0.03
+   http://www.softwarediamonds/packages/Test-TestUtil-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-TestUtil-0.04
 
 
 =head2 3.1.2 Copyright.
@@ -226,12 +226,12 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_TestUtil.pm                           0.03    2003/06/13 revised 0.02
- MANIFEST                                                     0.03    2003/06/13 generated, replaces 0.02
- Makefile.PL                                                  0.03    2003/06/13 generated, replaces 0.02
- README                                                       0.03    2003/06/13 generated, replaces 0.02
- lib/Test/TestUtil.pm                                         1.05    2003/06/13 revised 1.04
- t/Test/TestUtil/TestUtil.t                                   0.02    2003/06/13 revised 0.01
+ lib/Docs/Site_SVD/Test_TestUtil.pm                           0.04    2003/06/14 revised 0.03
+ MANIFEST                                                     0.04    2003/06/14 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2003/06/14 generated, replaces 0.03
+ README                                                       0.04    2003/06/14 generated, replaces 0.03
+ lib/Test/TestUtil.pm                                         1.06    2003/06/14 revised 1.05
+ t/Test/TestUtil/TestUtil.t                                   0.03    2003/06/14 revised 0.02
  t/Test/TestUtil/Drivers/Driver.pm                            0.01    2003/06/12 unchanged
  t/Test/TestUtil/Drivers/Generate.pm                          0.01    2003/06/12 unchanged
  t/Test/TestUtil/Drivers/IO.pm                                0.01    2003/06/12 unchanged
@@ -239,33 +239,87 @@ consists of the following files:
 
 =head2 3.3 Changes
 
-Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
-test run
+The changes from the previous version are as follows:
 
-PERL_DL_NONLAZY=1 /usr/local/perl/bin/perl "-MExtUtils::Command::MM" "-e" "test_harness(0, 'blib/lib', 'blib/arch')" t/Test/TestUtil/TestUtil.t
-t/Test/TestUtil/TestUtil....# Test 18 got: '$VAR1 = '';
-' (t/Test/TestUtil/TestUtil.t at line 540 fail #17)
+=over 4
+
+=item our old friend visits again - DOS and UNIX text file incompatibility
+
+This impacts other modules. We have to examine all modules for
+this portability defect and correct any found defects.
+
+Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
+and Kingpin <mthurn@carbon> test runs.
+
+On Mr. Smokehouse's run email the got: VAR1 clearly showed extra white space
+line that is not present in the expected: VAR1. 
+In Mr. Kingpin's run the got: VAR1 and expected: VAR1 look visually the same.
+However, the Unix found a difference(s) and failed the test.
+
+For Mr. Smokehouse's run:
+
+PERL_DL_NONLAZY=1 /usr/local/bin/perl "-MExtUtils::Command::MM" "-e" "test_harness(0, 'blib/lib', 'blib/arch')" t/Test/TestUtil/TestUtil.t
+t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
+
+
+ Software Version Description
+
+
+ for
+
+
+ Test::TestUtil - Utilites for Test::STDmaker and ExtUtils::SVDmaker
+
+
+ Revision: C
+
+[snip]
+
+
+(t/Test/TestUtil/TestUtil.t at line 565 fail #17)
 #    Expected: '$VAR1 = '\\=head1 Title Page
 
-The I<pm2datah> method is not returning any data for Test 18. This will also cause
-the test of I<pm2data>, test 19 to fail.
-The I<pm2datah> is searching for the string "\n__DATA__\n".
 
-The "\n" character on Perl is a logical end of line character sequence.
-The "\n" end of line is different on Mr. Smokehouse's Unix operating system
-than on my Windows NT operating system.
-The test file was created under MSWin32 and uses a MSWin32 "\n".
-Under UNIX, I<pm2datah> method will look for the Unix "\n"
-and there will not be any.
+ Software Version Description
 
-Changed "\n__DATA__\n" to /[\012\015]__DATA__/. 
 
-During the clean-up for CPAN, broke the I<format_hash_table>
-method for tables in hash of hash format. 
-Fixed the break, added test 29 to the I<t/Test/TestUtil/TestUtil.t>
-test script for this
-feature, and added a discusssion of this feature in
-POD discription for I<format_hash_table>
+ for
+
+
+ Test::TestUtil - Utilites for Test::STDmaker and ExtUtils::SVDmaker
+
+What we have before, was a totally "failure to communicate." aka Cool Hand Luke. 
+VAR1 was empty. Now VAR1 has something. It is not completely dead.
+One probable cause is the Unix operating system must be producing two Unix \012 new lines 
+for a Microsoft single newline \015\012.
+Without being able to examine the test with a debugger, the only way to verify
+this is to provide the fix and see if the problem goes away when this great group
+of testers try for the fourth time. 
+
+Revised I<fin> method to take a handle, change I<pm2datah> method handle,  I<$fh>, 
+to binary by adding a I<binmode $fh> statement, and pass the actual
+thru the I<fin> method for test 18.
+
+Use I<fin($fh)> to read in the data for I<pm2data>, test 19 Unit Under Test (UUT),
+instead of using the raw file handle.
+
+The I<fin> method takes any \015\012 combination and changes it into the 
+logical Perl new line, I<"\n">, for the current operating system.
+
+=item Namespace conflict
+
+Someone is complain that they have uploaded a Test-Tester before my upload
+Changed Test-Tester to Test-Tech and submitted a registration for Test-Tech.
+This impacts documentation for this module.
+
+=item Setup Unix Portability Test Machine
+
+This development of portable code with the tester on one side of the big pond called
+the Atlantic ocean and the developer on the other side could use some improvement.
+Need to take one of Crystal's PCs she is not using and put up Free BSD for portability
+testing. This way the CPAN version numbers will not be spining so fast.
+
+=back
 
 =head2 3.4 Adaptation data.
 
@@ -300,8 +354,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Test-TestUtil-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-TestUtil-0.03
+   http://www.softwarediamonds/packages/Test-TestUtil-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-TestUtil-0.04
 
 
 =head2 3.6.1 Installation support.
@@ -320,50 +374,8 @@ as part of the installation:
 
 =head2 3.7 Possible problems and known errors
 
-The I<pm2datah> method determines the data section
-by searching for the token /[\012\015]__DATA__/.
-Currently the I<pm2datah> test only tests for
-"\n__DATA__" for the current operating system.
-The test should be for all operating systems,
-not just the current one.
-
-The Test::TestUtil program module is the foundation
-program module for testing
-and must be rock solid to ensure the quality of
-the Units that it will be testing.
-Testing of this module should be proactive and
-not dumped upon the end-user.
-
-There is still much work needed to ensure the quality 
-of this module as follows:
-
-=over 4
-
-=item *
-
-State the functional requirements for each method 
-including not only the GO paths but also what to
-expect for the NOGO paths
-
-=item *
-
-All the tests are GO path tests. Should add
-NOGO tests.
-
-=item *
-
-Add the requirements addressed as I<# R: >
-comment to the tests
-
-=item *
-
-Write a program to build a matrix to trace
-test step to the requirements and vice versa by
-parsing the I<# R: > comments.
-Automatically insert the matrix in the
-Test::TestUtil POD.
-
-=back
+The I<pm2datah> and I<pm2data> methods determines the data section
+by searching for the expression /
 
 =head1 4.0 NOTES
 
@@ -430,17 +442,20 @@ __DATA__
 
 
 
+
+
+
 DISTNAME: Test-TestUtil^
-VERSION : 0.03^
+VERSION : 0.04^
 REPOSITORY_DIR: packages^
 FREEZE: 1^
 
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.02^
+PREVIOUS_RELEASE: 0.03^
+REVISION: C^
 CHANGE2CURRENT:  ^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: Low level utilities originally developed to support Test::STDmaker^
-REVISION: B^
 TITLE   : Test::TestUtil - Utilites for Test::STDmaker and ExtUtils::SVDmaker^
 END_USER: General Public^
 COPYRIGHT: copyright  2003 Software Diamonds^
@@ -473,33 +488,88 @@ EXE_FILES:  ^
 
 CHANGES:
 
-Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
-test run
+The changes from the previous version are as follows:
 
-PERL_DL_NONLAZY=1 /usr/local/perl/bin/perl "-MExtUtils::Command::MM" "-e" "test_harness(0, 'blib/lib', 'blib/arch')" t/Test/TestUtil/TestUtil.t
-t/Test/TestUtil/TestUtil....# Test 18 got: '$VAR1 = '';
-' (t/Test/TestUtil/TestUtil.t at line 540 fail #17)
+=over 4
+
+=item our old friend visits again - DOS and UNIX text file incompatibility
+
+This impacts other modules. We have to examine all modules for
+this portability defect and correct any found defects.
+
+Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
+and Kingpin <mthurn@carbon> test runs.
+
+On Mr. Smokehouse's run email the got: VAR1 clearly showed extra white space
+line that is not present in the expected: VAR1. 
+In Mr. Kingpin's run the got: VAR1 and expected: VAR1 look visually the same.
+However, the Unix found a difference(s) and failed the test.
+
+For Mr. Smokehouse's run:
+
+PERL_DL_NONLAZY=1 /usr/local/bin/perl "-MExtUtils::Command::MM" "-e" "test_harness(0, 'blib/lib', 'blib/arch')" t/Test/TestUtil/TestUtil.t
+t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
+
+
+ Software Version Description
+
+
+ for
+
+
+ ${TITLE}
+
+
+ Revision: ${REVISION}
+
+[snip]
+
+
+(t/Test/TestUtil/TestUtil.t at line 565 fail #17)
 #    Expected: '$VAR1 = '\\=head1 Title Page
 
-The I<pm2datah> method is not returning any data for Test 18. This will also cause
-the test of I<pm2data>, test 19 to fail.
-The I<pm2datah> is searching for the string "\n__DATA__\n".
 
-The "\n" character on Perl is a logical end of line character sequence.
-The "\n" end of line is different on Mr. Smokehouse's Unix operating system
-than on my Windows NT operating system.
-The test file was created under MSWin32 and uses a MSWin32 "\n".
-Under UNIX, I<pm2datah> method will look for the Unix "\n"
-and there will not be any.
+ Software Version Description
 
-Changed "\n__DATA__\n" to /[\012\015]__DATA__/. 
 
-During the clean-up for CPAN, broke the I<format_hash_table>
-method for tables in hash of hash format. 
-Fixed the break, added test 29 to the I<t/Test/TestUtil/TestUtil.t>
-test script for this
-feature, and added a discusssion of this feature in
-POD discription for I<format_hash_table>
+ for
+
+
+ ${TITLE}
+
+What we have before, was a totally "failure to communicate." aka Cool Hand Luke. 
+VAR1 was empty. Now VAR1 has something. It is not completely dead.
+One probable cause is the Unix operating system must be producing two Unix \012 new lines 
+for a Microsoft single newline \015\012.
+Without being able to examine the test with a debugger, the only way to verify
+this is to provide the fix and see if the problem goes away when this great group
+of testers try for the fourth time. 
+
+Revised I<fin> method to take a handle, change I<pm2datah> method handle,  I<$fh>, 
+to binary by adding a I<binmode $fh> statement, and pass the actual
+thru the I<fin> method for test 18.
+
+Use I<fin($fh)> to read in the data for I<pm2data>, test 19 Unit Under Test (UUT),
+instead of using the raw file handle.
+
+The I<fin> method takes any \015\012 combination and changes it into the 
+logical Perl new line, I<"\n">, for the current operating system.
+
+=item Namespace conflict
+
+Someone is complain that they have uploaded a Test-Tester before my upload
+Changed Test-Tester to Test-Tech and submitted a registration for Test-Tech.
+This impacts documentation for this module.
+
+=item Setup Unix Portability Test Machine
+
+This development of portable code with the tester on one side of the big pond called
+the Atlantic ocean and the developer on the other side could use some improvement.
+Need to take one of Crystal's PCs she is not using and put up Free BSD for portability
+testing. This way the CPAN version numbers will not be spining so fast.
+
+=back
+
 ^
 
 DOCUMENT_OVERVIEW:
@@ -517,8 +587,8 @@ The dependency of the program modules in the Test::STDmaker ExtUtils::SVDmaker
 US DOD STD2167A bundle is as follows:
 
  Test::TestUtil
-     Test::Tester
-        DataPort::FormDB
+     Test::Tech
+        DataPort::DataFile DataPort::FileType::FormDB
             Test::STDmaker ExtUtils::SVDmaker
 
 Test software should be short and not depend on any other
@@ -560,13 +630,17 @@ that the program module vocabulary is present.
 ^
 
 PROBLEMS:
+The I<pm2datah> and I<pm2data> methods determines the data section
+by searching for the expression /^[\012\015]__DATA__$/.
+If somehow this sequence appears in the code,
+it will cause a failure of these methods.
+Thus, when using this function, statments such as the
+below (if it is even a valid statement) cannot be used:
+
+ $var = '
+ __DATA__
+ ';
 
-The I<pm2datah> method determines the data section
-by searching for the token /[\012\015]__DATA__/.
-Currently the I<pm2datah> test only tests for
-"\n__DATA__" for the current operating system.
-The test should be for all operating systems,
-not just the current one.
 
 The Test::TestUtil program module is the foundation
 program module for testing
